export interface P2PRequestPacket {
    readonly data?: unknown;
    readonly procedure: string;
}
export interface P2PResponsePacket {
    readonly data: unknown;
}
export interface P2PMessagePacket {
    readonly data?: unknown;
    readonly event: string;
}
export interface P2PPenalty {
}
export interface P2PInfoOptions {
    readonly [key: string]: unknown;
}
export interface P2PPeerInfo {
    readonly ipAddress: string;
    readonly wsPort: number;
}
export interface P2PDiscoveredPeerInfo extends P2PPeerInfo {
    readonly height: number;
    readonly updatedAt?: Date;
    readonly os?: string;
    readonly version: string;
    readonly [key: string]: unknown;
}
export interface P2PNodeInfo {
    readonly os: string;
    readonly version: string;
    readonly nethash: string;
    readonly wsPort: number;
    readonly height: number;
    readonly [key: string]: unknown;
}
export interface P2PClosePacket {
    readonly peerInfo: P2PDiscoveredPeerInfo;
    readonly code: number;
    readonly reason?: string;
}
export interface P2PConfig {
    readonly blacklistedPeers: ReadonlyArray<P2PPeerInfo>;
    readonly connectTimeout?: number;
    readonly ackTimeout?: number;
    readonly hostAddress?: string;
    readonly seedPeers: ReadonlyArray<P2PPeerInfo>;
    readonly nodeInfo: P2PNodeInfo;
    readonly wsEngine?: string;
    readonly discoveryInterval?: number;
    readonly peerSelectionForSendRequest?: P2PPeerSelectionForSendRequest;
    readonly peerSelectionForConnection?: P2PPeerSelectionForConnection;
    readonly peerHandshakeCheck?: P2PCheckPeerCompatibility;
}
export interface P2PNetworkStatus {
    readonly newPeers: ReadonlyArray<P2PDiscoveredPeerInfo>;
    readonly triedPeers: ReadonlyArray<P2PDiscoveredPeerInfo>;
    readonly connectedPeers: ReadonlyArray<P2PDiscoveredPeerInfo>;
}
export interface ProtocolNodeInfo {
    readonly broadhash: string;
    readonly nethash: string;
    readonly height: number;
    readonly nonce: string;
    readonly os?: string;
    readonly version: string;
    readonly wsPort: number;
    readonly httpPort: number;
    readonly [key: string]: unknown;
}
export declare type P2PPeerSelectionForSendRequest = (peers: ReadonlyArray<P2PDiscoveredPeerInfo>, nodeInfo?: P2PNodeInfo, numOfPeers?: number) => ReadonlyArray<P2PDiscoveredPeerInfo>;
export declare type P2PPeerSelectionForConnection = (peers: ReadonlyArray<P2PDiscoveredPeerInfo>, nodeInfo?: P2PNodeInfo) => ReadonlyArray<P2PDiscoveredPeerInfo>;
export interface P2PCompatibilityCheckReturnType {
    readonly success: boolean;
    readonly errors?: string[];
}
export declare type P2PCheckPeerCompatibility = (headers: P2PDiscoveredPeerInfo, nodeInfo: P2PNodeInfo) => P2PCompatibilityCheckReturnType;
export interface ProtocolPeerInfo {
    readonly ip: string;
    readonly broadhash: string;
    readonly height: number;
    readonly nonce: string;
    readonly os?: string;
    readonly version: string;
    readonly wsPort: number;
    readonly httpPort?: number;
    readonly [key: string]: unknown;
}
export interface ProtocolPeerInfoList {
    readonly peers: ReadonlyArray<ProtocolPeerInfo>;
    readonly success: boolean;
}
export interface ProtocolRPCRequestPacket {
    readonly data: unknown;
    readonly procedure: string;
    readonly type: string;
}
export interface ProtocolMessagePacket {
    readonly data: unknown;
    readonly event: string;
}
