import { EventEmitter } from 'events';
import { SCClientSocket } from 'socketcluster-client';
import { SCServerSocket } from 'socketcluster-server';
import { P2PDiscoveredPeerInfo, P2PMessagePacket, P2PNodeInfo, P2PPeerInfo, P2PPeerSelectionForConnection, P2PPeerSelectionForSendRequest, P2PRequestPacket, P2PResponsePacket } from './p2p_types';
import { EVENT_CLOSE_OUTBOUND, EVENT_CONNECT_ABORT_OUTBOUND, EVENT_CONNECT_OUTBOUND, EVENT_FAILED_PEER_INFO_UPDATE, EVENT_INBOUND_SOCKET_ERROR, EVENT_MESSAGE_RECEIVED, EVENT_OUTBOUND_SOCKET_ERROR, EVENT_REQUEST_RECEIVED, EVENT_UPDATED_PEER_INFO, Peer, PeerConfig } from './peer';
export declare const EVENT_FAILED_TO_PUSH_NODE_INFO = "failedToPushNodeInfo";
export declare const EVENT_DISCOVERED_PEER = "discoveredPeer";
export declare const EVENT_FAILED_TO_FETCH_PEER_INFO = "failedToFetchPeerInfo";
export { EVENT_CLOSE_OUTBOUND, EVENT_CONNECT_OUTBOUND, EVENT_CONNECT_ABORT_OUTBOUND, EVENT_REQUEST_RECEIVED, EVENT_MESSAGE_RECEIVED, EVENT_OUTBOUND_SOCKET_ERROR, EVENT_INBOUND_SOCKET_ERROR, EVENT_UPDATED_PEER_INFO, EVENT_FAILED_PEER_INFO_UPDATE, };
interface PeerPoolConfig {
    readonly connectTimeout?: number;
    readonly ackTimeout?: number;
    readonly peerSelectionForSendRequest: P2PPeerSelectionForSendRequest;
    readonly peerSelectionForConnection: P2PPeerSelectionForConnection;
}
export declare const MAX_PEER_LIST_BATCH_SIZE = 100;
export declare const MAX_PEER_DISCOVERY_PROBE_SAMPLE_SIZE = 100;
export declare class PeerPool extends EventEmitter {
    private readonly _peerMap;
    private readonly _peerPoolConfig;
    private readonly _handlePeerRPC;
    private readonly _handlePeerMessage;
    private readonly _handlePeerConnect;
    private readonly _handlePeerConnectAbort;
    private readonly _handlePeerClose;
    private readonly _handlePeerOutboundSocketError;
    private readonly _handlePeerInboundSocketError;
    private readonly _handlePeerInfoUpdate;
    private readonly _handleFailedPeerInfoUpdate;
    private _nodeInfo;
    private readonly _peerSelectForSendRequest;
    private readonly _peerSelectForConnection;
    constructor(peerPoolConfig: PeerPoolConfig);
    applyNodeInfo(nodeInfo: P2PNodeInfo): void;
    readonly nodeInfo: P2PNodeInfo | undefined;
    selectPeers(numOfPeers?: number): ReadonlyArray<P2PDiscoveredPeerInfo>;
    requestFromPeer(packet: P2PRequestPacket): Promise<P2PResponsePacket>;
    sendToPeers(message: P2PMessagePacket): void;
    fetchStatusAndCreatePeers(seedPeers: ReadonlyArray<P2PPeerInfo>, nodeInfo: P2PNodeInfo, peerConfig: PeerConfig): Promise<ReadonlyArray<P2PDiscoveredPeerInfo>>;
    runDiscovery(knownPeers: ReadonlyArray<P2PDiscoveredPeerInfo>, blacklist: ReadonlyArray<P2PPeerInfo>): Promise<ReadonlyArray<P2PDiscoveredPeerInfo>>;
    selectPeersAndConnect(peers: ReadonlyArray<P2PDiscoveredPeerInfo>): ReadonlyArray<P2PDiscoveredPeerInfo>;
    addPeer(peerInfo: P2PDiscoveredPeerInfo, inboundSocket?: SCServerSocket): Peer;
    addDiscoveredPeer(detailedPeerInfo: P2PDiscoveredPeerInfo, inboundSocket?: SCServerSocket): Peer;
    addInboundPeer(peerId: string, peerInfo: P2PDiscoveredPeerInfo, socket: SCServerSocket): boolean;
    addOutboundPeer(peerId: string, peerInfo: P2PDiscoveredPeerInfo, socket: SCClientSocket): boolean;
    removeAllPeers(): void;
    getAllPeerInfos(): ReadonlyArray<P2PDiscoveredPeerInfo>;
    getAllPeers(): ReadonlyArray<Peer>;
    getPeer(peerId: string): Peer | undefined;
    hasPeer(peerId: string): boolean;
    removePeer(peerId: string): boolean;
    private _applyNodeInfoOnPeer;
    private _bindHandlersToPeer;
    private _unbindHandlersFromPeer;
}
